@@ -18,11 +18,14 @@
  */
 package org.apache.myfaces.commons.converter;
 
-import com.sun.facelets.tag.MetaRuleset;
-import com.sun.facelets.tag.jsf.ConvertHandler;
-import com.sun.facelets.tag.jsf.ConverterConfig;
+import javax.faces.view.facelets.ConverterConfig;
+import javax.faces.view.facelets.ConverterHandler;
+import javax.faces.view.facelets.MetaRuleset;
 
-public class ConverterBaseTagHandler extends ConvertHandler
+import org.apache.myfaces.buildtools.maven2.plugin.builder.annotation.JSFFaceletTag;
+
+@JSFFaceletTag
+public class ConverterBaseTagHandler extends ConverterHandler
 {
 
     public ConverterBaseTagHandler(ConverterConfig config)
@@ -36,7 +39,7 @@ public class ConverterBaseTagHandler extends ConvertHandler
         MetaRuleset ruleSet = super.createMetaRuleset(type);
         
         //Add rule to handle EL expressions
-        ruleSet.addRule(_ConverterRule.Instance);
+        ruleSet.addRule(_ConverterRule.INSTANCE);
         
         return ruleSet;
     }
