@@ -18,7 +18,8 @@
  */
 package org.apache.myfaces.commons.exporter.util;
 
-public interface ExporterConstants {
+public interface ExporterConstants
+{
     public static String EXPORTER_TABLE_ID = "exporterTableId";
     public static String EXPORTER_FILE_NAME = "exporterFileName";
     public static String EXPORTER_FILE_TYPE = "exporterFileType";
