@@ -21,13 +21,13 @@ package org.apache.myfaces.commons.util;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import javax.el.ValueExpression;
 import javax.faces.FactoryFinder;
 import javax.faces.application.Application;
 import javax.faces.application.ApplicationFactory;
 import javax.faces.application.FacesMessage;
 import javax.faces.component.UIComponent;
 import javax.faces.context.FacesContext;
-import javax.faces.el.ValueBinding;
 import java.text.MessageFormat;
 import java.util.Locale;
 import java.util.MissingResourceException;
@@ -42,11 +42,11 @@ import java.util.ResourceBundle;
  * @see FacesMessage
  * @see java.util.ResourceBundle
  *
- * @author Thomas Spiegl (latest modification by $Author: lu4242 $)
+ * @author Thomas Spiegl (latest modification by $Author: struberg $)
  * @author Manfred Geiler
  * @author Sean Schofield
  * @author Stpehan Strittmatter
- * @version $Revision: 1034621 $ $Date: 2010-11-12 20:34:04 -0500 (Fri, 12 Nov 2010) $
+ * @version $Revision: 1186797 $ $Date: 2011-10-20 08:36:24 -0500 (Thu, 20 Oct 2011) $
  */
 public final class MessageUtils
 {
@@ -199,8 +199,9 @@ public final class MessageUtils
                                   String forClientId,
                                   FacesContext facesContext)
     {
-        if(log.isTraceEnabled()) {
-          log.trace("adding message " + messageId + " for clientId " + forClientId);
+        if(log.isTraceEnabled())
+        {
+            log.trace("adding message " + messageId + " for clientId " + forClientId);
         }
         facesContext.addMessage(forClientId,
                                 getMessage(severity, messageId, args, facesContext));
@@ -213,8 +214,9 @@ public final class MessageUtils
             String forClientId,
             FacesContext facesContext)
     {
-        if(log.isTraceEnabled()) {
-        log.trace("adding message " + messageId + " for clientId " + forClientId);
+        if(log.isTraceEnabled())
+        {
+            log.trace("adding message " + messageId + " for clientId " + forClientId);
         }
         facesContext.addMessage(forClientId,
                   getMessage(bundleBaseName, severity, messageId, args, facesContext));
@@ -232,12 +234,17 @@ public final class MessageUtils
     {
         String localizedStr = null;
         if(params == null || msgtext == null)
+        {
             return msgtext;
+        }
 
+        StringBuffer b = new StringBuffer(100);
+        MessageFormat mf = new MessageFormat(msgtext);
         if(locale != null)
         {
-            MessageFormat mf = new MessageFormat(msgtext,locale);            
-            localizedStr = mf.format(params);
+            mf.setLocale(locale);
+            b.append(mf.format(((Object) (params))));
+            localizedStr = b.toString();
         }
         return localizedStr;
     }
@@ -256,8 +263,11 @@ public final class MessageUtils
         {
             locale = context.getViewRoot().getLocale();
             if(locale == null)
+            {
                 locale = Locale.getDefault();
-        } else
+            }
+        }
+        else
         {
             locale = Locale.getDefault();
         }
@@ -278,7 +288,8 @@ public final class MessageUtils
                 bundle = ResourceBundle.getBundle(bundleName, locale, getCurrentLoader(bundleName));
                 summary = bundle.getString(messageId);
             }
-            catch (MissingResourceException e) {
+            catch (MissingResourceException e)
+            {
                 // NoOp
             }
         }
@@ -294,7 +305,8 @@ public final class MessageUtils
                 }
                 summary = bundle.getString(messageId);
             }
-            catch(MissingResourceException e) {
+            catch(MissingResourceException e)
+            {
                 // NoOp
             }
         }
@@ -315,7 +327,8 @@ public final class MessageUtils
             {
                 detail = bundle.getString(messageId + DETAIL_SUFFIX);
             }
-            catch(MissingResourceException e) {
+            catch(MissingResourceException e)
+            {
                 // NoOp
             }
             return new ParametrizableFacesMessage(summary, detail, params, locale);
@@ -328,14 +341,16 @@ public final class MessageUtils
                 detail = substituteParams(locale,
                     bundle.getString(messageId + DETAIL_SUFFIX), params);
             }
-            catch(MissingResourceException e) {
+            catch(MissingResourceException e)
+            {
                 // NoOp
             }
             return new FacesMessage(summary, detail);
         }
     }
     
-    public static FacesMessage getMessageFromBundle(String bundleBaseName, FacesContext context, Locale locale, String messageId, Object params[])
+    public static FacesMessage getMessageFromBundle(String bundleBaseName, FacesContext context,
+                                                    Locale locale, String messageId, Object params[])
     {
         String summary = null;
         String detail = null;
@@ -349,7 +364,8 @@ public final class MessageUtils
                 bundle = ResourceBundle.getBundle(bundleName, locale, getCurrentLoader(bundleName));
                 summary = bundle.getString(messageId);
             }
-            catch (MissingResourceException e) {
+            catch (MissingResourceException e)
+            {
                 // NoOp
             }
         }
@@ -365,7 +381,8 @@ public final class MessageUtils
                 }
                 summary = bundle.getString(messageId);
             }
-            catch(MissingResourceException e) {
+            catch(MissingResourceException e)
+            {
                 // NoOp
             }
         }
@@ -381,7 +398,8 @@ public final class MessageUtils
                 }
                 summary = bundle.getString(messageId);
             }
-            catch(MissingResourceException e) {
+            catch(MissingResourceException e)
+            {
                 // NoOp
             }
         }
@@ -403,7 +421,8 @@ public final class MessageUtils
             {
                 detail = bundle.getString(messageId + DETAIL_SUFFIX);
             }
-            catch(MissingResourceException e) {
+            catch(MissingResourceException e)
+            {
                 // NoOp
             }
             return new ParametrizableFacesMessage(summary, detail, params, locale);
@@ -416,7 +435,8 @@ public final class MessageUtils
                 detail = substituteParams(locale,
                     bundle.getString(messageId + DETAIL_SUFFIX), params);
             }
-            catch(MissingResourceException e) {
+            catch(MissingResourceException e)
+            {
                 // NoOp
             }
             return new FacesMessage(summary, detail);
@@ -441,17 +461,21 @@ public final class MessageUtils
      * 
      * @return  currently applicable Locale for this request.
      */
-    public static Locale getCurrentLocale() {
+    public static Locale getCurrentLocale()
+    {
         return getCurrentLocale(FacesContext.getCurrentInstance());
     }
     
-    public static Locale getCurrentLocale(FacesContext context) {
+    public static Locale getCurrentLocale(FacesContext context)
+    {
         Locale locale;
         if(context != null && context.getViewRoot() != null)
         {
             locale = context.getViewRoot().getLocale();
             if(locale == null)
+            {
                 locale = Locale.getDefault();
+            }
         }
         else
         {
@@ -468,7 +492,8 @@ public final class MessageUtils
      * @param params parameters to set at localized message
      * @return generated FacesMessage
      */
-    public static FacesMessage getMessage(FacesMessage.Severity severity, String bundleBaseName, String messageId, Object params[])
+    public static FacesMessage getMessage(FacesMessage.Severity severity, String bundleBaseName,
+                                          String messageId, Object params[])
     {
       FacesMessage msg = getMessage(bundleBaseName, messageId, params);
       msg.setSeverity(severity);
@@ -514,7 +539,8 @@ public final class MessageUtils
       {
           summary = bundle.getString(messageId);
       }
-      catch (MissingResourceException e) {
+      catch (MissingResourceException e)
+      {
         // NoOp
       }
 
@@ -531,7 +557,8 @@ public final class MessageUtils
           detail = substituteParams(bundle.getLocale(),
               bundle.getString(messageId + DETAIL_SUFFIX), params);
       }
-      catch(MissingResourceException e) {
+      catch(MissingResourceException e)
+      {
         // NoOp
       }
 
@@ -564,15 +591,22 @@ public final class MessageUtils
     public static FacesMessage getMessage(FacesContext context, String messageId, Object params[])
     {
         if(context == null || messageId == null)
+        {
             throw new NullPointerException(" context " + context + " messageId " + messageId);
+        }
+
         Locale locale = getCurrentLocale(context);
         if(null == locale)
+        {
             throw new NullPointerException(" locale " + locale);
+        }
+
         FacesMessage message = getMessage(locale, messageId, params);
         if(message != null)
         {
             return message;
-        } else
+        }
+        else
         {
             // TODO /FIX:  Note that this has fallback behavior to default Locale for message,
             // but similar behavior above does not.  The methods should probably behave
@@ -581,18 +615,26 @@ public final class MessageUtils
         }
     }
     
-    public static FacesMessage getMessage(String bundleBaseName, FacesContext context, String messageId, Object params[])
+    public static FacesMessage getMessage(String bundleBaseName, FacesContext context,
+                                          String messageId, Object params[])
     {
         if(context == null || messageId == null)
+        {
             throw new NullPointerException(" context " + context + " messageId " + messageId);
+        }
+
         Locale locale = getCurrentLocale(context);
         if(null == locale)
+        {
             throw new NullPointerException(" locale " + locale);
+        }
+
         FacesMessage message = getMessageFromBundle(bundleBaseName, context, locale, messageId, params);
         if(message != null)
         {
             return message;
-        } else
+        }
+        else
         {
             // TODO /FIX:  Note that this has fallback behavior to default Locale for message,
             // but similar behavior above does not.  The methods should probably behave
@@ -601,14 +643,19 @@ public final class MessageUtils
         }
     }
     
-    public static Object getLabel(FacesContext facesContext, UIComponent component) {
+    public static Object getLabel(FacesContext facesContext, UIComponent component)
+    {
         Object label = component.getAttributes().get("label");
         if(label != null)
+        {
             return label;
-        
-        ValueBinding expression = component.getValueBinding("label");
+        }
+
+        ValueExpression expression = component.getValueExpression("label");
         if(expression != null)
+        {
             return expression;
+        }
         
         //If no label is not specified, use clientId
         return component.getClientId( facesContext );
@@ -620,9 +667,11 @@ public final class MessageUtils
         if(context != null)
         {
             return context.getApplication();
-        } else
+        }
+        else
         {
-            ApplicationFactory afactory = (ApplicationFactory)FactoryFinder.getFactory("javax.faces.application.ApplicationFactory");
+            ApplicationFactory afactory = (ApplicationFactory)
+                    FactoryFinder.getFactory("javax.faces.application.ApplicationFactory");
             return afactory.getApplication();
         }
     }
